pub struct Prompt { /* private fields */ }Expand description
Combined system + user messages for an inference call.
Implementations
Sourceimpl Prompt
impl Prompt
Sourcepub fn new(system: Arc<str>, user: Arc<str>) -> Self
pub fn new(system: Arc<str>, user: Arc<str>) -> Self
Create a new Prompt from raw system and user strings.
Sourcepub fn generate(
workflow: Arc<dyn WorkflowLike>,
context: &mut dyn ContextLike,
capability: &Capability,
) -> Self
pub fn generate( workflow: Arc<dyn WorkflowLike>, context: &mut dyn ContextLike, capability: &Capability, ) -> Self
Inference a Prompt from a workflow for a given model capability.
This is the high-level orchestration used by the inference pipeline. It is deterministic and side-effect free aside from evaluating rules via the provided context.